==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/gtkgui/generic.h <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GENERIC_GUI_H
#define GENERIC_GUI_H

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
//#include <jmixer.h>
#include "profile.h"
#include "lamegui.h"
#include "icegui.h"
#include <jutils.h>
#include <../generic.h>

/* FIXME: support more than 6 chan */
#define NOIDX 12
#define NOPOS 13
#define NOTOGGLE 12
#define TOGGLE 13

/* FIXME: cleaning up */

class Stream_mixer;

extern GtkWidget *window, *statusbar, *mic, *linein, *speakout;
extern guint contextid;
extern GtkWidget *maintab, *vbox;
/* FIXME: mah, maybe a struct like ProgressData */
extern GtkWidget *winil, *nbook, *mp3entry, *winprof;
extern unsigned int channum[7];
extern unsigned int maxpos;
extern unsigned int numc;
extern Stream_mixer *mixer;
extern GList *listachan;
extern int guibitrate;
extern float storevol[MAX_CHANNELS];
extern char *pathfile;
extern struct lamesave *lametmp;
extern struct icesave *icetmp;
/* id of "select_row" handler */
extern guint blockid[7];
extern bool state; 

#endif

==> MuSE-0.7.1.tar.gz: MuSE-0.7.1/gtkgui/generic.h <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GENERIC_GUI_H
#define GENERIC_GUI_H

#include <stdio.h>
#include <string.h>
#include <gtk/gtk.h>
//#include <jmixer.h>
//#include "profile.h"
#include <lamegui.h>
#include <icegui.h>
#include <vumeters.h>
#include <jutils.h>
#include <../generic.h>

/* FIXME: support more than 6 chan */
#define NOIDX 12
#define NOPOS 13
#define NOTOGGLE 12
#define TOGGLE 13
/* experimental */
//#define WITH_SPEED

/* FIXME: cleaning up */

class Stream_mixer;

extern GtkWidget *window, *statusbar, *mic, *linein, *speakout;
extern guint contextid;
extern GtkWidget *maintab, *vbox, *fix;
/* FIXME: mah, maybe a struct like ProgressData */
extern GtkWidget *winil, *nbook, *mp3entry, *winprof, *winvu;
extern unsigned int channum[7];
extern unsigned int maxpos;
extern unsigned int numc;
extern Stream_mixer *mixer;
extern GList *listachan;
extern bool firstlame, firstice;
extern float storevol[MAX_CHANNELS];
extern char *pathfile;
extern struct lamesave lametmp;
extern struct icesave icetmp;
extern struct vumeters *vu;
/* id of "select_row" handler */
extern guint blockid[7];
extern bool state; 
extern bool vu_status;
#endif
